==========
``parser``
==========

The command-line parsing framework is split up into a handful of sub-modules:

- ``parser.argument``
- ``parser.context`` (not to be confused with the top level ``context``!)
- ``parser.parser``

API docs for all are below.

.. automodule:: invoke.parser.parser
    :member-order: by-source
.. automodule:: invoke.parser.context
.. automodule:: invoke.parser.argument
